@@ -83,7 +83,6 @@ ENABLE_USER_SITE = None
 USER_SITE = None
 USER_BASE = None
 
-_is_64bit = (getattr(sys, 'maxsize', None) or getattr(sys, 'maxint')) > 2**32
 _is_pypy = hasattr(sys, 'pypy_version_info')
 _is_jython = sys.platform[:4] == 'java'
 if _is_jython:
@@ -237,12 +236,9 @@ def addsitepackages(known_paths, sys_prefix=sys.prefix, exec_prefix=sys.exec_pre
                             os.path.join(prefix, "lib", "site-python"),
                             os.path.join(prefix, "python" + sys.version[:3], "lib-dynload")]
                 lib64_dir = os.path.join(prefix, "lib64", "python" + sys.version[:3], "site-packages")
-                if (os.path.exists(lib64_dir) and
+                if (os.path.exists(lib64_dir) and 
                     os.path.realpath(lib64_dir) not in [os.path.realpath(p) for p in sitedirs]):
-                    if _is_64bit:
-                        sitedirs.insert(0, lib64_dir)
-                    else:
-                        sitedirs.append(lib64_dir)
+                    sitedirs.append(lib64_dir)
                 try:
                     # sys.getobjects only available in --with-pydebug build
                     sys.getobjects
@@ -479,7 +475,7 @@ def setcopyright():
     elif _is_pypy:
         builtins.credits = _Printer(
             "credits",
-            "PyPy is maintained by the PyPy developers: http://pypy.org/")
+            "PyPy is maintained by the PyPy developers: http://codespeak.net/pypy")
     else:
         builtins.credits = _Printer("credits", """\
     Thanks to CWI, CNRI, BeOpen.com, Zope Corporation and a cast of thousands
@@ -560,17 +556,13 @@ def virtual_install_main_packages():
     if _is_jython:
         paths = [os.path.join(sys.real_prefix, 'Lib')]
     elif _is_pypy:
-        if sys.version_info > (3, 2):
-            cpyver = '%d' % sys.version_info[0]
-        elif sys.pypy_version_info >= (1, 5):
+        if sys.pypy_version_info >= (1, 5):
             cpyver = '%d.%d' % sys.version_info[:2]
         else:
             cpyver = '%d.%d.%d' % sys.version_info[:3]
         paths = [os.path.join(sys.real_prefix, 'lib_pypy'),
+                 os.path.join(sys.real_prefix, 'lib-python', 'modified-%s' % cpyver),
                  os.path.join(sys.real_prefix, 'lib-python', cpyver)]
-        if sys.pypy_version_info < (1, 9):
-            paths.insert(1, os.path.join(sys.real_prefix,
-                                         'lib-python', 'modified-%s' % cpyver))
         hardcoded_relative_dirs = paths[:] # for the special 'darwin' case below
         #
         # This is hardcoded in the Python executable, but relative to sys.prefix:
@@ -585,23 +577,10 @@ def virtual_install_main_packages():
         hardcoded_relative_dirs = paths[:] # for the special 'darwin' case below
         lib64_path = os.path.join(sys.real_prefix, 'lib64', 'python'+sys.version[:3])
         if os.path.exists(lib64_path):
-            if _is_64bit:
-                paths.insert(0, lib64_path)
-            else:
-                paths.append(lib64_path)
-        # This is hardcoded in the Python executable, but relative to
-        # sys.prefix.  Debian change: we need to add the multiarch triplet
-        # here, which is where the real stuff lives.  As per PEP 421, in
-        # Python 3.3+, this lives in sys.implementation, while in Python 2.7
-        # it lives in sys.
-        try:
-            arch = getattr(sys, 'implementation', sys)._multiarch
-        except AttributeError:
-            # This is a non-multiarch aware Python.  Fallback to the old way.
-            arch = sys.platform
-        plat_path = os.path.join(sys.real_prefix, 'lib',
-                                 'python'+sys.version[:3],
-                                 'plat-%s' % arch)
+            paths.append(lib64_path)
+        # This is hardcoded in the Python executable, but relative to sys.prefix:
+        plat_path = os.path.join(sys.real_prefix, 'lib', 'python'+sys.version[:3],
+                                 'plat-%s' % sys.platform)
         if os.path.exists(plat_path):
             paths.append(plat_path)
     # This is hardcoded in the Python executable, but
@@ -631,14 +610,14 @@ def force_global_eggs_after_local_site_packages():
     maintains the "least surprise" result that packages in the
     virtualenv always mask global packages, never the other way
     around.
-
+    
     """
     egginsert = getattr(sys, '__egginsert', 0)
     for i, path in enumerate(sys.path):
         if i > egginsert and path.startswith(sys.prefix):
             egginsert = i
     sys.__egginsert = egginsert + 1
-
+    
 def virtual_addsitepackages(known_paths):
     force_global_eggs_after_local_site_packages()
     return addsitepackages(known_paths, sys_prefix=sys.real_prefix)
